summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAllan McRae <allan@archlinux.org>2020-01-19 00:30:54 +0100
committerAllan McRae <allan@archlinux.org>2020-01-27 08:53:50 +0100
commit2856a7dea3c0d4584e126b5ca5957e13e23f83d1 (patch)
treed333e0c680b3c2c93f694d95b8a373049c30c012
parent2e32d51a262fef398a94a17c0a0d4ff3233990b5 (diff)
downloadpacman-2856a7dea3c0d4584e126b5ca5957e13e23f83d1.tar.gz
pacman-2856a7dea3c0d4584e126b5ca5957e13e23f83d1.tar.xz
Increase maximum database size
We previously has the maximum database size as 25MB. This was set in the days before repos had as many packages as they do now, and before we started distributing files databases. Increase this limit to 128MB. Signed-off-by: Allan McRae <allan@archlinux.org>
-rw-r--r--lib/libalpm/be_sync.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/libalpm/be_sync.c b/lib/libalpm/be_sync.c
index 07d2b4ae..e33ec7bd 100644
--- a/lib/libalpm/be_sync.c
+++ b/lib/libalpm/be_sync.c
@@ -223,8 +223,8 @@ int SYMEXPORT alpm_db_update(int force, alpm_db_t *db)
size_t len;
int sig_ret = 0;
- /* set hard upper limit of 25MiB */
- payload.max_size = 25 * 1024 * 1024;
+ /* set hard upper limit of 128MiB */
+ payload.max_size = 128 * 1024 * 1024;
/* print server + filename into a buffer */
len = strlen(server) + strlen(db->treename) + strlen(dbext) + 2;